ensureInitialized method
Ensures the binary is ready. Can be called at startup.
Implementation
Future<void> ensureInitialized() async {
// We can just call the sync version which handles everything
_getBinaryPathSync();
}
Ensures the binary is ready. Can be called at startup.
Future<void> ensureInitialized() async {
// We can just call the sync version which handles everything
_getBinaryPathSync();
}