RustLinterService class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
analyzeSync(
String content) → List - Synchronous analysis. Note: This spawns a new process for each file.
-
ensureInitialized(
) → Future< void> - Ensures the binary is ready. Can be called at startup.
-
fixSync(
String content, int offset, int length) → Map< String, dynamic> ? - Synchronous fix generation.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → RustLinterService
-
final
Constants
- kPluginVersion → const String